@@ -100,12 +100,13 @@
   {% if temporary -%} on commit preserve rows {%- endif %}
   as
     {{ sql }}
-
 {%- endmacro %}
 
 
 {% macro oracle__create_table_as(temporary, relation, sql) -%}
   {%- set sql_header = config.get('sql_header', none) -%}
+  {%- set parallel = config.get('parallel', none) -%}
+  {%- set compression_clause = config.get('table_compression_clause', none) -%}
 
   {{ sql_header if sql_header is not none }}
 
@@ -113,6 +114,10 @@
     global temporary
   {%- endif %} table {{ relation.include(schema=(not temporary)) }}
   {% if temporary -%} on commit preserve rows {%- endif %}
+  {% if not temporary -%}
+    {% if parallel %} parallel {{ parallel }}{% endif %}
+    {% if compression_clause %} {{ compression_clause }} {% endif %}
+  {%- endif %}
   as
     {{ sql }}
 
@@ -346,13 +351,9 @@
   {{ return(load_result('list_relations_without_caching').table) }}
 {% endmacro %}
 
-{% macro oracle__current_timestamp() -%}
-  CURRENT_TIMESTAMP
-{%- endmacro %}
-
 {% macro oracle__make_temp_relation(base_relation, suffix) %}
     {% set dt = modules.datetime.datetime.now() %}
-    {% set dtstring = dt.strftime("%H%M%S") %}
+    {% set dtstring = dt.strftime("%H%M%S%f") %}
     {% set tmp_identifier = 'o$pt_' ~ base_relation.identifier ~ dtstring %}
     {% set tmp_relation = base_relation.incorporate(
                                 path={"identifier": tmp_identifier, "schema": None}) -%}
